.. code-block:: bash

	Usage: cli config [OPTIONS] [KEY]
	
	  Set and view config.
	
	Options:
	  --get TEXT    get config parameter
	  --add TEXT    set config parameter
	  -l, --list    list config parameters
	  --unset TEXT  unset config parameter
	  --type TEXT   type to interpret config value to set or get. Allowed options:
	                bool, int
	
	  -h, --help    Show this message and exit.
	
	

